@@ -9,6 +9,11 @@ sys.path.insert(0, "../")
 
 from compathelper import _long, _unicode, _bytes
 
+os.environ['GSETTINGS_BACKEND'] = 'memory'
+# support a separate build tree, so look in build dir first
+os.environ['GSETTINGS_SCHEMA_DIR'] = os.environ.get('TESTS_BUILDDIR', 
+        os.path.dirname(__file__))
+
 from gi.repository import GLib
 from gi.repository import GObject
 from gi.repository import Gdk
@@ -19,6 +24,11 @@ from gi.repository import GdkPixbuf
 import gi.overrides as overrides
 import gi.types
 
+# in general we don't want tests to raise warnings, except when explicitly
+# testing with bad values; in those cases it will temporarily be set back to
+# ERROR
+GLib.log_set_always_fatal(GLib.LogLevelFlags.LEVEL_WARNING)
+
 class TestGLib(unittest.TestCase):
 
     def test_gvariant_create(self):
@@ -1859,10 +1869,6 @@ class TestGtk(unittest.TestCase):
 
 class TestGio(unittest.TestCase):
     def setUp(self):
-        os.environ['GSETTINGS_BACKEND'] = 'memory'
-        # support a separate build tree, so look in build dir first
-        os.environ['GSETTINGS_SCHEMA_DIR'] = os.environ.get('TESTS_BUILDDIR', 
-                os.path.dirname(__file__))
         self.settings = Gio.Settings('org.gnome.test')
         # we change the values in the tests, so set them to predictable start
         # value
